@@ -21,29 +21,25 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import cast
 
 from .annotation import AnnotationMixin
 from .bookmark import BookmarkMixin
+from .const import BODY_ALLOW_NAMED_RANGE_TAGS
 from .element import Element, PropDef, PropDefBool, register_element_class
 from .form import FormMixin
+from .mixin_link import LinkMixin
 from .mixin_named_range import NRMixin
 from .note import NoteMixin
 from .office_forms import OfficeFormsMixin
 from .reference import ReferenceMixin
 from .section import SectionMixin
+from .table import Table
 from .tracked_changes import TrackedChangesMixin
+from .variable_declaration import VarDeclMixin
 
-if TYPE_CHECKING:
-    from .table import Table
-
-BODY_NR_TAGS = {
-    "office:chart",
-    "office:drawing",
-    "office:presentation",
-    "office:spreadsheet",
-    "office:text",
-}
+# for compatibility with version <= 3.18.1
+BODY_NR_TAGS = BODY_ALLOW_NAMED_RANGE_TAGS
 
 
 class Body(Element):
@@ -85,7 +81,7 @@ class Body(Element):
         Returns:
             list[Table]: A list of all Table elements.
         """
-        return self.get_elements("descendant::table:table")  # type: ignore[return-value]
+        return cast(list[Table], self.get_elements("descendant::table:table"))
 
     sheets = tables
 
@@ -121,8 +117,13 @@ class Body(Element):
 
     get_sheet = get_table
 
+    @property
+    def allow_named_range(self) -> bool:
+        """Return True if the current body allows named ranges."""
+        return self.tag in BODY_ALLOW_NAMED_RANGE_TAGS
 
-class Chart(NRMixin, Body):
+
+class Chart(VarDeclMixin, NRMixin, Body):
     """Root of the Chart document content, "office:chart"."""
 
     _tag: str = "office:chart"
@@ -136,7 +137,7 @@ class Database(Body):
     _properties: tuple[PropDef | PropDefBool, ...] = ()
 
 
-class Drawing(NRMixin, Body):
+class Drawing(VarDeclMixin, NRMixin, Body):
     """Root of the Drawing document content, "office:drawing"."""
 
     _tag: str = "office:drawing"
@@ -150,14 +151,14 @@ class Image(Body):
     _properties: tuple[PropDef | PropDefBool, ...] = ()
 
 
-class Presentation(NRMixin, Body):
+class Presentation(LinkMixin, VarDeclMixin, NRMixin, Body):
     """Root of the Presentation document content, "office:presentation"."""
 
     _tag: str = "office:presentation"
     _properties: tuple[PropDef | PropDefBool, ...] = ()
 
 
-class Spreadsheet(AnnotationMixin, NRMixin, Body):
+class Spreadsheet(LinkMixin, AnnotationMixin, NRMixin, Body):
     """Root of the Spreadsheet document content, "office:spreadsheet"."""
 
     _tag: str = "office:spreadsheet"
@@ -165,6 +166,8 @@ class Spreadsheet(AnnotationMixin, NRMixin, Body):
 
 
 class Text(
+    LinkMixin,
+    VarDeclMixin,
     NRMixin,
     FormMixin,
     TrackedChangesMixin,
