@@ -17,6 +17,13 @@
 # Authors (odfdo project): jerome.dumonteil@gmail.com
 # The odfdo project is a derivative work of the lpod-python project:
 # https://github.com/lpod/lpod-python
+"""Command-line script to highlight text in an ODF document.
+
+This script searches for a given regular expression pattern in an ODF text
+document and applies a style to the matching text. The style can include
+italic, bold, text color, and background color.
+"""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser, Namespace
@@ -29,8 +36,16 @@ PROG = "odfdo-highlight"
 
 
 def configure_parser() -> ArgumentParser:
-    description = "Search and highlight text in ODF file using regex pattern."
-    parser = ArgumentParser(prog=PROG, description=description)
+    description = (
+        "Search for a regular expression pattern in an ODF text document "
+        "and apply a highlighting style to the matching text. "
+        "The style can include italic, bold, text color, and background color."
+    )
+    epilog = (
+        "This tool is useful for visually emphasizing specific content "
+        "within your ODF documents based on search patterns."
+    )
+    parser = ArgumentParser(prog=PROG, description=description, epilog=epilog)
 
     parser.add_argument(
         "-i",
