@@ -19,6 +19,12 @@
 # https://github.com/lpod/lpod-python
 # Authors: Hervé Cauwelier <herve@itaapy.com>
 #          David Versmisse <david.versmisse@itaapy.com>
+"""Command-line script to display the content of an ODF document.
+
+This script dumps the text content, styles, and metadata of an ODF file
+to the standard output or into a specified directory.
+"""
+
 from __future__ import annotations
 
 import sys
@@ -32,12 +38,16 @@ PROG = "odfdo-show"
 
 
 def configure_parser() -> ArgumentParser:
-    description = description = (
-        "Dump text from an OpenDocument file to the standard "
-        "output, optionally styles and meta (and the Pictures/* "
-        'in "-o <DIR>" mode)'
+    description = (
+        "Display various parts of an ODF document, including text content, "
+        "styles, and metadata, to standard output or a specified directory."
     )
-    parser = ArgumentParser(prog=PROG, description=description)
+    epilog = (
+        "By default, the script dumps the main textual content. "
+        "Use options like -m (metadata), -s (styles), or -o (output directory) "
+        "to customize the output. When using -o, embedded pictures are also extracted."
+    )
+    parser = ArgumentParser(prog=PROG, description=description, epilog=epilog)
 
     parser.add_argument(
         "--version",
