@@ -977,3 +977,23 @@ def test_get_list_2():
     element.insert(List(["c"]), position=0)
     result = element.get_list(content="z")
     assert result is None
+
+
+def test_element_get_attribute_int_default_1():
+    element = Element.from_tag("<form:form/>")
+    result = element._get_attribute_int_default("form:tab-index", 0)
+    assert result == 0
+
+
+def test_element_get_attribute_int_default_2():
+    element = Element.from_tag("<form:form/>")
+    element._set_attribute_int_default("form:tab-index", 1, 0)
+    result = element._get_attribute_int_default("form:tab-index", 0)
+    assert result == 1
+
+
+def test_element_get_attribute_int_default_3():
+    element = Element.from_tag("<form:form/>")
+    element._set_attribute_int_default("form:tab-index", "not_an_int", 0)
+    result = element._get_attribute_int_default("form:tab-index", 0)
+    assert result == 0
